@@ -8,5 +8,7 @@ class Provider(abc.ABC):
     def __init__(self, throttling: Optional[Throttling] = None):
         self.throttling = throttling
 
-    def send(self, message: str):
-        raise NotImplementedError
+    def send(
+        self, message: str, exc: Optional[BaseException] = None, context: Optional[dict] = None
+    ):
+        raise NotImplementedError()
