@@ -1,4 +1,3 @@
-import abc
 import threading
 import time
 import typing
@@ -7,14 +6,20 @@ if typing.TYPE_CHECKING:
     from alarmer import Provider
 
 
-class Throttling(abc.ABC):
+class Throttling:
     def __init__(self):
         self.last_time = time.time()
         self.lock = threading.Lock()
 
-    def __call__(self, provider: "Provider", message: str) -> bool:
+    def __call__(
+        self,
+        provider: "typing.Union[Provider,typing.Callable]",
+        message: str,
+        exc: typing.Optional[BaseException] = None,
+        context: typing.Optional[dict] = None,
+    ) -> bool:
         with self.lock:
-            if time.time() - self.last_time < 1:
+            if time.time() - self.last_time < 5:
                 return False
             self.last_time = time.time()
             return True
